==================
SEAMM Psi4 Plug-in
==================

.. image:: https://img.shields.io/github/issues-pr-raw/molssi-seamm/psi4_step
   :target: https://github.com/molssi-seamm/psi4_step/pulls
   :alt: GitHub pull requests

.. image:: https://github.com/molssi-seamm/psi4_step/workflows/CI/badge.svg
   :target: https://github.com/molssi-seamm/psi4_step/actions
   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/psi4_step/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/molssi-seamm/psi4_step
   :alt: Code Coverage

.. image:: https://github.com/molssi-seamm/psi4_step/workflows/CodeQL/badge.svg
   :target: https://github.com/molssi-seamm/psi4_step/security/code-scanning
   :alt: Code Quality

.. image:: https://github.com/molssi-seamm/psi4_step/workflows/Documentation/badge.svg
   :target: https://molssi-seamm.github.io/psi4_step/index.html
   :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/psi4_step/shield.svg
   :target: https://pyup.io/repos/github/molssi-seamm/psi4_step/
   :alt: Updates for Dependencies

.. image:: https://img.shields.io/pypi/v/psi4_step.svg
   :target: https://pypi.python.org/pypi/psi4_step
   :alt: PyPi VERSION

A SEAMM plug-in to setup, run and analyze quantum chemistry
calculations using Psi4.

* Free software: BSD-3-Clause
* Documentation: https://molssi-seamm.github.io/psi4_step/index.html
* Code: https://github.com/molssi-seamm/psi4_step

Features
--------

* About 100 methods supported, including HF, DFT, coupled-cluster, CI
  and MCSCF
* About DFT functionals supported.
* Wide range of basis sets.
* Single-point energy.
* Geometry optimization.
* Second derivatives of the energy.
* Results can be stored in flowchart variables or tables_.

.. _tables: https://molssi-seamm.github.io/table_step/index.html

Acknowledgements
----------------

This package was created with Cookiecutter_ and the `molssi-seamm/cookiecutter-seamm-plugin`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`molssi-seamm/cookiecutter-seamm-plugin`: https://github.com/molssi-seamm/cookiecutter-seamm-plugin

Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the `National Science Foundation`_ under
award OAC-1547580 and CHE-2136142.

.. _MolSSI: https://www.molssi.org
.. _`National Science Foundation`: https://www.nsf.gov
